==> apache-james-mailbox-api-3.3.0-sources.jar: org/apache/james/mailbox/events/GroupAlreadyRegistered.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.events;

public class GroupAlreadyRegistered extends RuntimeException {
    private final Group group;

    public GroupAlreadyRegistered(Group group) {
        super(group.getClass().getCanonicalName() + " is already Registered and thus can not be used.");
        this.group = group;
    }

    public Group getGroup() {
        return group;
    }
}

==> apache-james-mailbox-api-3.5.0-sources.jar: org/apache/james/mailbox/events/GroupAlreadyRegistered.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.events;

public class GroupAlreadyRegistered extends RuntimeException {
    private final Group group;

    public GroupAlreadyRegistered(Group group) {
        super(group.asString() + " is already Registered and thus can not be used.");
        this.group = group;
    }

    public Group getGroup() {
        return group;
    }
}
